@@ -36,7 +36,7 @@
 //! build = "build.rs"
 //!
 //! [build-dependencies]
-//! embed-resource = "1.6"
+//! embed-resource = "1.7"
 //! ```
 //!
 //! In `build.rs`:
@@ -91,7 +91,6 @@
 
 #[cfg(any(not(target_os = "windows"), all(target_os = "windows", target_env = "msvc")))]
 extern crate cc;
-extern crate toml;
 #[cfg(all(target_os = "windows", target_env = "msvc"))]
 extern crate vswhom;
 #[cfg(all(target_os = "windows", target_env = "msvc"))]
@@ -112,9 +111,8 @@ use self::windows_msvc::*;
 #[cfg(all(target_os = "windows", not(target_env = "msvc")))]
 use self::windows_not_msvc::*;
 
-use std::{env, fs};
-use toml::Value as TomlValue;
-use toml::map::Map as TomlMap;
+use std::env;
+use std::fmt::Display;
 use std::path::{Path, PathBuf};
 
 
@@ -131,8 +129,7 @@ use std::path::{Path, PathBuf};
 /// Note that this does *nothing* if building with rustc before 1.50.0 and there's a library in the crate,
 /// since the resource is linked to the library, if any, instead of the binaries.
 ///
-/// Since rustc 1.50.0, the resource is linked only to the binaries
-/// (unless there are none, in which case it's also linked to the library).
+/// Since rustc 1.50.0, the resource is linked only to the binaries.
 ///
 /// # Examples
 ///
@@ -146,44 +143,55 @@ use std::path::{Path, PathBuf};
 ///     embed_resource::compile("checksums.rc");
 /// }
 /// ```
-#[inline]
 pub fn compile<T: AsRef<Path>>(resource_file: T) {
-    compile_impl(resource_file.as_ref())
+    if let Some((prefix, out_dir, out_file)) = compile_impl(resource_file.as_ref()) {
+        if rustc_version::version().expect("couldn't get rustc version") >= rustc_version::Version::new(1, 50, 0) {
+            println!("cargo:rustc-link-arg-bins={}", out_file);
+        } else {
+            // Cargo pre-0.51.0 (rustc pre-1.50.0) compat
+            // Doesn't work when the calling crate has a library
+            println!("cargo:rustc-link-search=native={}", out_dir);
+            println!("cargo:rustc-link-lib=dylib={}", prefix);
+        }
+    }
 }
 
-fn compile_impl(resource_file: &Path) {
+/// Likewise, but only for select binaries.
+///
+/// Only available since rustc 1.55.0, does nothing before.
+///
+/// # Examples
+///
+/// ```rust,no_run
+/// extern crate embed_resource;
+///
+/// fn main() {
+///     embed_resource::compile_for("assets/poke-a-mango.rc", &["poke-a-mango", "poke-a-mango-installer"]);
+///     embed_resource::compile_for("assets/uninstaller.rc", &["unins001"]);
+/// }
+/// ```
+pub fn compile_for<T: AsRef<Path>, J: Display, I: IntoIterator<Item = J>>(resource_file: T, for_bins: I) {
+    if let Some((_, _, out_file)) = compile_impl(resource_file.as_ref()) {
+        for bin in for_bins {
+            println!("cargo:rustc-link-arg-bin={}={}", bin, out_file);
+        }
+    }
+}
+
+fn compile_impl(resource_file: &Path) -> Option<(&str, String, String)> {
     let comp = ResourceCompiler::new();
     if comp.is_supported() {
         let prefix = &resource_file.file_stem().expect("resource_file has no stem").to_str().expect("resource_file's stem not UTF-8");
         let out_dir = env::var("OUT_DIR").expect("No OUT_DIR env var");
 
         let out_file = comp.compile_resource(&out_dir, &prefix, resource_file.to_str().expect("resource_file not UTF-8"));
-        let hasbins = fs::read_to_string("Cargo.toml")
-            .unwrap_or_else(|err| {
-                eprintln!("Couldn't read Cargo.toml: {}; assuming src/main.rs or S_ISDIR(src/bin/)", err);
-                String::new()
-            })
-            .parse::<TomlValue>()
-            .unwrap_or_else(|err| {
-                eprintln!("Couldn't parse Cargo.toml: {}; assuming src/main.rs or S_ISDIR(src/bin/)", err);
-                TomlValue::Table(TomlMap::new())
-            })
-            .as_table()
-            .map(|t| t.contains_key("bin"))
-            .unwrap_or(false) || (Path::new("src/main.rs").exists() || Path::new("src/bin").is_dir());
-        eprintln!("Final verdict: crate has binaries: {}", hasbins);
-
-        if hasbins && rustc_version::version().expect("couldn't get rustc version") >= rustc_version::Version::new(1, 50, 0) {
-            println!("cargo:rustc-link-arg-bins={}", out_file);
-        } else {
-            // Cargo pre-0.51.0 (rustc pre-1.50.0) compat
-            // Only links to the calling crate's library
-            println!("cargo:rustc-link-search=native={}", out_dir);
-            println!("cargo:rustc-link-lib=dylib={}", prefix);
-        }
+        Some((prefix, out_dir, out_file))
+    } else {
+        None
     }
 }
 
+
 /// Find MSVC build tools other than the compiler and linker
 ///
 /// On Windows + MSVC this can be used try to find tools such as `MIDL.EXE` in Windows Kits and/or SDK directories.
